"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Backup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    SOURCE_CLUSTER_ID_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    INDICES_FIELD_NUMBER: builtins.int
    ELASTICSEARCH_VERSION_FIELD_NUMBER: builtins.int
    SIZE_BYTES_FIELD_NUMBER: builtins.int
    INDICES_TOTAL_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Required. ID of the backup."""
    folder_id: builtins.str
    """ID of the folder that the backup belongs to."""
    source_cluster_id: builtins.str
    """ID of the associated Elasticsearch cluster."""
    elasticsearch_version: builtins.str
    """Elasticsearch version used to create the snapshot"""
    size_bytes: builtins.int
    """Total size of all indices in backup. in bytes"""
    indices_total: builtins.int
    """Total count of indices in backup"""
    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when the backup operation was started."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when the backup was created (i.e. when the backup operation completed)."""

    @property
    def indices(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Indices names. (max 100)"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        source_cluster_id: builtins.str = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        indices: collections.abc.Iterable[builtins.str] | None = ...,
        elasticsearch_version: builtins.str = ...,
        size_bytes: builtins.int = ...,
        indices_total: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "elasticsearch_version", b"elasticsearch_version", "folder_id", b"folder_id", "id", b"id", "indices", b"indices", "indices_total", b"indices_total", "size_bytes", b"size_bytes", "source_cluster_id", b"source_cluster_id", "started_at", b"started_at"]) -> None: ...

global___Backup = Backup



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/apploadbalancer/v1/virtual_host.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from yandex.cloud.apploadbalancer.v1 import payload_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_payload__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/apploadbalancer/v1/virtual_host.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1egoogle/protobuf/duration.proto\x1a-yandex/cloud/apploadbalancer/v1/payload.proto\x1a\x1dyandex/cloud/validation.proto\"\xdd\x02\n\x0bVirtualHost\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tauthority\x18\x02 \x03(\t\x12\x36\n\x06routes\x18\x03 \x03(\x0b\x32&.yandex.cloud.apploadbalancer.v1.Route\x12S\n\x16modify_request_headers\x18\x04 \x03(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.HeaderModification\x12T\n\x17modify_response_headers\x18\x05 \x03(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.HeaderModification\x12\x44\n\rroute_options\x18\x06 \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.RouteOptions\"\x8b\x02\n\x0cRouteOptions\x12S\n\x16modify_request_headers\x18\x01 \x03(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.HeaderModification\x12T\n\x17modify_response_headers\x18\x02 \x03(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.HeaderModification\x12\x33\n\x04rbac\x18\x03 \x01(\x0b\x32%.yandex.cloud.apploadbalancer.v1.RBAC\x12\x1b\n\x13security_profile_id\x18\x04 \x01(\t\"\xcb\x01\n\x04RBAC\x12\x42\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32,.yandex.cloud.apploadbalancer.v1.RBAC.ActionB\x04\xe8\xc7\x31\x01\x12H\n\nprincipals\x18\x02 \x03(\x0b\x32+.yandex.cloud.apploadbalancer.v1.PrincipalsB\x07\x82\xc8\x31\x03>=1\"5\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\t\n\x05\x41LLOW\x10\x01\x12\x08\n\x04\x44\x45NY\x10\x02\"Y\n\nPrincipals\x12K\n\x0e\x61nd_principals\x18\x01 \x03(\x0b\x32*.yandex.cloud.apploadbalancer.v1.PrincipalB\x07\x82\xc8\x31\x03>=1\"\xf1\x01\n\tPrincipal\x12J\n\x06header\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.apploadbalancer.v1.Principal.HeaderMatcherH\x00\x12\x13\n\tremote_ip\x18\x02 \x01(\tH\x00\x12\r\n\x03\x61ny\x18\x03 \x01(\x08H\x00\x1a`\n\rHeaderMatcher\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.StringMatchB\x12\n\nidentifier\x12\x04\xc0\xc1\x31\x01\"x\n\x12HeaderModification\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x06\x61ppend\x18\x02 \x01(\tH\x00\x12\x11\n\x07replace\x18\x03 \x01(\tH\x00\x12\x10\n\x06remove\x18\x04 \x01(\x08H\x00\x12\x10\n\x06rename\x18\x05 \x01(\tH\x00\x42\x0b\n\toperation\"\xe8\x01\n\x05Route\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12:\n\x04http\x18\x02 \x01(\x0b\x32*.yandex.cloud.apploadbalancer.v1.HttpRouteH\x00\x12:\n\x04grpc\x18\x03 \x01(\x0b\x32*.yandex.cloud.apploadbalancer.v1.GrpcRouteH\x00\x12\x44\n\rroute_options\x18\x04 \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.RouteOptionsB\r\n\x05route\x12\x04\xc0\xc1\x31\x01\"\xb5\x02\n\tHttpRoute\x12>\n\x05match\x18\x01 \x01(\x0b\x32/.yandex.cloud.apploadbalancer.v1.HttpRouteMatch\x12\x41\n\x05route\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.apploadbalancer.v1.HttpRouteActionH\x00\x12\x43\n\x08redirect\x18\x03 \x01(\x0b\x32/.yandex.cloud.apploadbalancer.v1.RedirectActionH\x00\x12P\n\x0f\x64irect_response\x18\x04 \x01(\x0b\x32\x35.yandex.cloud.apploadbalancer.v1.DirectResponseActionH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\"\xf4\x01\n\tGrpcRoute\x12>\n\x05match\x18\x01 \x01(\x0b\x32/.yandex.cloud.apploadbalancer.v1.GrpcRouteMatch\x12\x41\n\x05route\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.apploadbalancer.v1.GrpcRouteActionH\x00\x12T\n\x0fstatus_response\x18\x03 \x01(\x0b\x32\x39.yandex.cloud.apploadbalancer.v1.GrpcStatusResponseActionH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\"a\n\x0eHttpRouteMatch\x12\x13\n\x0bhttp_method\x18\x01 \x03(\t\x12:\n\x04path\x18\x02 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.StringMatch\"L\n\x0eGrpcRouteMatch\x12:\n\x04\x66qmn\x18\x01 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.StringMatch\"b\n\x0bStringMatch\x12\x15\n\x0b\x65xact_match\x18\x01 \x01(\tH\x00\x12\x16\n\x0cprefix_match\x18\x02 \x01(\tH\x00\x12\x15\n\x0bregex_match\x18\x03 \x01(\tH\x00\x42\r\n\x05match\x12\x04\xc0\xc1\x31\x01\"\xfa\x02\n\x0eRedirectAction\x12\x16\n\x0ereplace_scheme\x18\x01 \x01(\t\x12\x14\n\x0creplace_host\x18\x02 \x01(\t\x12\x14\n\x0creplace_port\x18\x03 \x01(\x03\x12\x16\n\x0creplace_path\x18\x04 \x01(\tH\x00\x12\x18\n\x0ereplace_prefix\x18\x05 \x01(\tH\x00\x12\x14\n\x0cremove_query\x18\x06 \x01(\x08\x12[\n\rresponse_code\x18\x07 \x01(\x0e\x32\x44.yandex.cloud.apploadbalancer.v1.RedirectAction.RedirectResponseCode\"w\n\x14RedirectResponseCode\x12\x15\n\x11MOVED_PERMANENTLY\x10\x00\x12\t\n\x05\x46OUND\x10\x01\x12\r\n\tSEE_OTHER\x10\x02\x12\x16\n\x12TEMPORARY_REDIRECT\x10\x03\x12\x16\n\x12PERMANENT_REDIRECT\x10\x04\x42\x06\n\x04path\"k\n\x14\x44irectResponseAction\x12\x1b\n\x06status\x18\x01 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31\x30\x30-599\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yandex.cloud.apploadbalancer.v1.Payload\"\x82\x02\n\x18GrpcStatusResponseAction\x12P\n\x06status\x18\x01 \x01(\x0e\x32@.yandex.cloud.apploadbalancer.v1.GrpcStatusResponseAction.Status\"\x93\x01\n\x06Status\x12\x06\n\x02OK\x10\x00\x12\x14\n\x10INVALID_ARGUMENT\x10\x01\x12\r\n\tNOT_FOUND\x10\x02\x12\x15\n\x11PERMISSION_DENIED\x10\x03\x12\x13\n\x0fUNAUTHENTICATED\x10\x04\x12\x11\n\rUNIMPLEMENTED\x10\x05\x12\x0c\n\x08INTERNAL\x10\x06\x12\x0f\n\x0bUNAVAILABLE\x10\x07\"\x8c\x02\n\x0fHttpRouteAction\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12*\n\x07timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\x0cidle_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x16\n\x0chost_rewrite\x18\x04 \x01(\tH\x00\x12\x1b\n\x11\x61uto_host_rewrite\x18\x05 \x01(\x08H\x00\x12\x16\n\x0eprefix_rewrite\x18\x06 \x01(\t\x12\x15\n\rupgrade_types\x18\x07 \x03(\tB\x18\n\x16host_rewrite_specifier\"\xe1\x01\n\x0fGrpcRouteAction\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x0bmax_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\x0cidle_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x16\n\x0chost_rewrite\x18\x04 \x01(\tH\x00\x12\x1b\n\x11\x61uto_host_rewrite\x18\x05 \x01(\x08H\x00\x42\x18\n\x16host_rewrite_specifierBz\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.apploadbalancer.v1.virtual_host_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer'
  _VIRTUALHOST.fields_by_name['name']._options = None
  _VIRTUALHOST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _RBAC.fields_by_name['action']._options = None
  _RBAC.fields_by_name['action']._serialized_options = b'\350\3071\001'
  _RBAC.fields_by_name['principals']._options = None
  _RBAC.fields_by_name['principals']._serialized_options = b'\202\3101\003>=1'
  _PRINCIPALS.fields_by_name['and_principals']._options = None
  _PRINCIPALS.fields_by_name['and_principals']._serialized_options = b'\202\3101\003>=1'
  _PRINCIPAL_HEADERMATCHER.fields_by_name['name']._options = None
  _PRINCIPAL_HEADERMATCHER.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _PRINCIPAL.oneofs_by_name['identifier']._options = None
  _PRINCIPAL.oneofs_by_name['identifier']._serialized_options = b'\300\3011\001'
  _ROUTE.oneofs_by_name['route']._options = None
  _ROUTE.oneofs_by_name['route']._serialized_options = b'\300\3011\001'
  _ROUTE.fields_by_name['name']._options = None
  _ROUTE.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _HTTPROUTE.oneofs_by_name['action']._options = None
  _HTTPROUTE.oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _GRPCROUTE.oneofs_by_name['action']._options = None
  _GRPCROUTE.oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _STRINGMATCH.oneofs_by_name['match']._options = None
  _STRINGMATCH.oneofs_by_name['match']._serialized_options = b'\300\3011\001'
  _DIRECTRESPONSEACTION.fields_by_name['status']._options = None
  _DIRECTRESPONSEACTION.fields_by_name['status']._serialized_options = b'\372\3071\007100-599'
  _HTTPROUTEACTION.fields_by_name['backend_group_id']._options = None
  _HTTPROUTEACTION.fields_by_name['backend_group_id']._serialized_options = b'\350\3071\001'
  _GRPCROUTEACTION.fields_by_name['backend_group_id']._options = None
  _GRPCROUTEACTION.fields_by_name['backend_group_id']._serialized_options = b'\350\3071\001'
  _globals['_VIRTUALHOST']._serialized_start=198
  _globals['_VIRTUALHOST']._serialized_end=547
  _globals['_ROUTEOPTIONS']._serialized_start=550
  _globals['_ROUTEOPTIONS']._serialized_end=817
  _globals['_RBAC']._serialized_start=820
  _globals['_RBAC']._serialized_end=1023
  _globals['_RBAC_ACTION']._serialized_start=970
  _globals['_RBAC_ACTION']._serialized_end=1023
  _globals['_PRINCIPALS']._serialized_start=1025
  _globals['_PRINCIPALS']._serialized_end=1114
  _globals['_PRINCIPAL']._serialized_start=1117
  _globals['_PRINCIPAL']._serialized_end=1358
  _globals['_PRINCIPAL_HEADERMATCHER']._serialized_start=1242
  _globals['_PRINCIPAL_HEADERMATCHER']._serialized_end=1338
  _globals['_HEADERMODIFICATION']._serialized_start=1360
  _globals['_HEADERMODIFICATION']._serialized_end=1480
  _globals['_ROUTE']._serialized_start=1483
  _globals['_ROUTE']._serialized_end=1715
  _globals['_HTTPROUTE']._serialized_start=1718
  _globals['_HTTPROUTE']._serialized_end=2027
  _globals['_GRPCROUTE']._serialized_start=2030
  _globals['_GRPCROUTE']._serialized_end=2274
  _globals['_HTTPROUTEMATCH']._serialized_start=2276
  _globals['_HTTPROUTEMATCH']._serialized_end=2373
  _globals['_GRPCROUTEMATCH']._serialized_start=2375
  _globals['_GRPCROUTEMATCH']._serialized_end=2451
  _globals['_STRINGMATCH']._serialized_start=2453
  _globals['_STRINGMATCH']._serialized_end=2551
  _globals['_REDIRECTACTION']._serialized_start=2554
  _globals['_REDIRECTACTION']._serialized_end=2932
  _globals['_REDIRECTACTION_REDIRECTRESPONSECODE']._serialized_start=2805
  _globals['_REDIRECTACTION_REDIRECTRESPONSECODE']._serialized_end=2924
  _globals['_DIRECTRESPONSEACTION']._serialized_start=2934
  _globals['_DIRECTRESPONSEACTION']._serialized_end=3041
  _globals['_GRPCSTATUSRESPONSEACTION']._serialized_start=3044
  _globals['_GRPCSTATUSRESPONSEACTION']._serialized_end=3302
  _globals['_GRPCSTATUSRESPONSEACTION_STATUS']._serialized_start=3155
  _globals['_GRPCSTATUSRESPONSEACTION_STATUS']._serialized_end=3302
  _globals['_HTTPROUTEACTION']._serialized_start=3305
  _globals['_HTTPROUTEACTION']._serialized_end=3573
  _globals['_GRPCROUTEACTION']._serialized_start=3576
  _globals['_GRPCROUTEACTION']._serialized_end=3801
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DnsZone(google.protobuf.message.Message):
    """A DNS zone. For details about the concept, see [DNS zones](/docs/dns/concepts/dns-zone)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    PRIVATE_VISIBILITY_FIELD_NUMBER: builtins.int
    PUBLIC_VISIBILITY_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the DNS zone. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the DNS zone belongs to."""
    name: builtins.str
    """Name of the DNS zone. 
    The name is unique within the folder.
    """
    description: builtins.str
    """Description of the DNS zone."""
    zone: builtins.str
    """DNS zone suffix."""
    deletion_protection: builtins.bool
    """Prevents accidental zone removal."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """DNS zone labels as `key:value` pairs."""

    @property
    def private_visibility(self) -> global___PrivateVisibility:
        """Privately visible zone settings.
        Specifies whether records within the zone are visible from a VPC networks only.
        """

    @property
    def public_visibility(self) -> global___PublicVisibility:
        """Publicly visible zone settings. 
        Indicates whether records within the zone are publicly visible.
        """

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        zone: builtins.str = ...,
        private_visibility: global___PrivateVisibility | None = ...,
        public_visibility: global___PublicVisibility | None = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "private_visibility", b"private_visibility", "public_visibility", b"public_visibility"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "private_visibility", b"private_visibility", "public_visibility", b"public_visibility", "zone", b"zone"]) -> None: ...

global___DnsZone = DnsZone

@typing.final
class RecordSet(google.protobuf.message.Message):
    """A record set. For details about the concept, see [Resource record](/docs/dns/concepts/resource-record)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Domain name."""
    type: builtins.str
    """Record type."""
    ttl: builtins.int
    """Time to live in seconds."""
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Data of the record set."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: builtins.str = ...,
        ttl: builtins.int = ...,
        data: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "name", b"name", "ttl", b"ttl", "type", b"type"]) -> None: ...

global___RecordSet = RecordSet

@typing.final
class PrivateVisibility(google.protobuf.message.Message):
    """Configuration for privately visible zones."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_IDS_FIELD_NUMBER: builtins.int
    @property
    def network_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Network IDs."""

    def __init__(
        self,
        *,
        network_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_ids", b"network_ids"]) -> None: ...

global___PrivateVisibility = PrivateVisibility

@typing.final
class PublicVisibility(google.protobuf.message.Message):
    """Configuration for publicly visible zones."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PublicVisibility = PublicVisibility



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/clickhouse/v1/user_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.mdb.clickhouse.v1 import user_pb2 as yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_user__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/mdb/clickhouse/v1/user_service.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a&yandex/cloud/operation/operation.proto\x1a)yandex/cloud/mdb/clickhouse/v1/user.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\"d\n\x0eGetUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\"r\n\x10ListUsersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"a\n\x11ListUsersResponse\x12\x33\n\x05users\x18\x01 \x03(\x0b\x32$.yandex.cloud.mdb.clickhouse.v1.User\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"x\n\x11\x43reateUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x41\n\tuser_spec\x18\x02 \x01(\x0b\x32(.yandex.cloud.mdb.clickhouse.v1.UserSpecB\x04\xe8\xc7\x31\x01\";\n\x12\x43reateUserMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\"\xf1\x02\n\x11UpdateUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1b\n\x08password\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05\x38-128\x12?\n\x0bpermissions\x18\x05 \x03(\x0b\x32*.yandex.cloud.mdb.clickhouse.v1.Permission\x12>\n\x08settings\x18\x06 \x01(\x0b\x32,.yandex.cloud.mdb.clickhouse.v1.UserSettings\x12\x39\n\x06quotas\x18\x07 \x03(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.UserQuota\";\n\x12UpdateUserMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\"g\n\x11\x44\x65leteUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\";\n\x12\x44\x65leteUserMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\"\xb0\x01\n\x1aGrantUserPermissionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\x12>\n\npermission\x18\x03 \x01(\x0b\x32*.yandex.cloud.mdb.clickhouse.v1.Permission\"D\n\x1bGrantUserPermissionMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\"\xa4\x01\n\x1bRevokeUserPermissionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\x12\x31\n\rdatabase_name\x18\x03 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"E\n\x1cRevokeUserPermissionMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t2\xad\x0b\n\x0bUserService\x12\xa3\x01\n\x03Get\x12..yandex.cloud.mdb.clickhouse.v1.GetUserRequest\x1a$.yandex.cloud.mdb.clickhouse.v1.User\"F\x82\xd3\xe4\x93\x02@\x12>/managed-clickhouse/v1/clusters/{cluster_id}/users/{user_name}\x12\xa7\x01\n\x04List\x12\x30.yandex.cloud.mdb.clickhouse.v1.ListUsersRequest\x1a\x31.yandex.cloud.mdb.clickhouse.v1.ListUsersResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/managed-clickhouse/v1/clusters/{cluster_id}/users\x12\xbb\x01\n\x06\x43reate\x12\x31.yandex.cloud.mdb.clickhouse.v1.CreateUserRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*\x1a\n\x12\x43reateUserMetadata\x12\x04User\x82\xd3\xe4\x93\x02\x37\"2/managed-clickhouse/v1/clusters/{cluster_id}/users:\x01*\x12\xc7\x01\n\x06Update\x12\x31.yandex.cloud.mdb.clickhouse.v1.UpdateUserRequest\x1a!.yandex.cloud.operation.Operation\"g\xb2\xd2*\x1a\n\x12UpdateUserMetadata\x12\x04User\x82\xd3\xe4\x93\x02\x43\x32>/managed-clickhouse/v1/clusters/{cluster_id}/users/{user_name}:\x01*\x12\xd5\x01\n\x06\x44\x65lete\x12\x31.yandex.cloud.mdb.clickhouse.v1.DeleteUserRequest\x1a!.yandex.cloud.operation.Operation\"u\xb2\xd2*+\n\x12\x44\x65leteUserMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02@*>/managed-clickhouse/v1/clusters/{cluster_id}/users/{user_name}\x12\xf3\x01\n\x0fGrantPermission\x12:.yandex.cloud.mdb.clickhouse.v1.GrantUserPermissionRequest\x1a!.yandex.cloud.operation.Operation\"\x80\x01\xb2\xd2*#\n\x1bGrantUserPermissionMetadata\x12\x04User\x82\xd3\xe4\x93\x02S\"N/managed-clickhouse/v1/clusters/{cluster_id}/users/{user_name}:grantPermission:\x01*\x12\xf7\x01\n\x10RevokePermission\x12;.yandex.cloud.mdb.clickhouse.v1.RevokeUserPermissionRequest\x1a!.yandex.cloud.operation.Operation\"\x82\x01\xb2\xd2*$\n\x1cRevokeUserPermissionMetadata\x12\x04User\x82\xd3\xe4\x93\x02T\"O/managed-clickhouse/v1/clusters/{cluster_id}/users/{user_name}:revokePermission:\x01*Bs\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.clickhouse.v1.user_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse'
  _GETUSERREQUEST.fields_by_name['cluster_id']._options = None
  _GETUSERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETUSERREQUEST.fields_by_name['user_name']._options = None
  _GETUSERREQUEST.fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _LISTUSERSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTUSERSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTUSERSREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTUSERSREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATEUSERREQUEST.fields_by_name['cluster_id']._options = None
  _CREATEUSERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEUSERREQUEST.fields_by_name['user_spec']._options = None
  _CREATEUSERREQUEST.fields_by_name['user_spec']._serialized_options = b'\350\3071\001'
  _UPDATEUSERREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATEUSERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEUSERREQUEST.fields_by_name['user_name']._options = None
  _UPDATEUSERREQUEST.fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _UPDATEUSERREQUEST.fields_by_name['password']._options = None
  _UPDATEUSERREQUEST.fields_by_name['password']._serialized_options = b'\212\3101\0058-128'
  _DELETEUSERREQUEST.fields_by_name['cluster_id']._options = None
  _DELETEUSERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEUSERREQUEST.fields_by_name['user_name']._options = None
  _DELETEUSERREQUEST.fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _GRANTUSERPERMISSIONREQUEST.fields_by_name['cluster_id']._options = None
  _GRANTUSERPERMISSIONREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GRANTUSERPERMISSIONREQUEST.fields_by_name['user_name']._options = None
  _GRANTUSERPERMISSIONREQUEST.fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _REVOKEUSERPERMISSIONREQUEST.fields_by_name['cluster_id']._options = None
  _REVOKEUSERPERMISSIONREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _REVOKEUSERPERMISSIONREQUEST.fields_by_name['user_name']._options = None
  _REVOKEUSERPERMISSIONREQUEST.fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _REVOKEUSERPERMISSIONREQUEST.fields_by_name['database_name']._options = None
  _REVOKEUSERPERMISSIONREQUEST.fields_by_name['database_name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _USERSERVICE.methods_by_name['Get']._options = None
  _USERSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002@\022>/managed-clickhouse/v1/clusters/{cluster_id}/users/{user_name}'
  _USERSERVICE.methods_by_name['List']._options = None
  _USERSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\0024\0222/managed-clickhouse/v1/clusters/{cluster_id}/users'
  _USERSERVICE.methods_by_name['Create']._options = None
  _USERSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\032\n\022CreateUserMetadata\022\004User\202\323\344\223\0027\"2/managed-clickhouse/v1/clusters/{cluster_id}/users:\001*'
  _USERSERVICE.methods_by_name['Update']._options = None
  _USERSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\032\n\022UpdateUserMetadata\022\004User\202\323\344\223\002C2>/managed-clickhouse/v1/clusters/{cluster_id}/users/{user_name}:\001*'
  _USERSERVICE.methods_by_name['Delete']._options = None
  _USERSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*+\n\022DeleteUserMetadata\022\025google.protobuf.Empty\202\323\344\223\002@*>/managed-clickhouse/v1/clusters/{cluster_id}/users/{user_name}'
  _USERSERVICE.methods_by_name['GrantPermission']._options = None
  _USERSERVICE.methods_by_name['GrantPermission']._serialized_options = b'\262\322*#\n\033GrantUserPermissionMetadata\022\004User\202\323\344\223\002S\"N/managed-clickhouse/v1/clusters/{cluster_id}/users/{user_name}:grantPermission:\001*'
  _USERSERVICE.methods_by_name['RevokePermission']._options = None
  _USERSERVICE.methods_by_name['RevokePermission']._serialized_options = b'\262\322*$\n\034RevokeUserPermissionMetadata\022\004User\202\323\344\223\002T\"O/managed-clickhouse/v1/clusters/{cluster_id}/users/{user_name}:revokePermission:\001*'
  _globals['_GETUSERREQUEST']._serialized_start=297
  _globals['_GETUSERREQUEST']._serialized_end=397
  _globals['_LISTUSERSREQUEST']._serialized_start=399
  _globals['_LISTUSERSREQUEST']._serialized_end=513
  _globals['_LISTUSERSRESPONSE']._serialized_start=515
  _globals['_LISTUSERSRESPONSE']._serialized_end=612
  _globals['_CREATEUSERREQUEST']._serialized_start=614
  _globals['_CREATEUSERREQUEST']._serialized_end=734
  _globals['_CREATEUSERMETADATA']._serialized_start=736
  _globals['_CREATEUSERMETADATA']._serialized_end=795
  _globals['_UPDATEUSERREQUEST']._serialized_start=798
  _globals['_UPDATEUSERREQUEST']._serialized_end=1167
  _globals['_UPDATEUSERMETADATA']._serialized_start=1169
  _globals['_UPDATEUSERMETADATA']._serialized_end=1228
  _globals['_DELETEUSERREQUEST']._serialized_start=1230
  _globals['_DELETEUSERREQUEST']._serialized_end=1333
  _globals['_DELETEUSERMETADATA']._serialized_start=1335
  _globals['_DELETEUSERMETADATA']._serialized_end=1394
  _globals['_GRANTUSERPERMISSIONREQUEST']._serialized_start=1397
  _globals['_GRANTUSERPERMISSIONREQUEST']._serialized_end=1573
  _globals['_GRANTUSERPERMISSIONMETADATA']._serialized_start=1575
  _globals['_GRANTUSERPERMISSIONMETADATA']._serialized_end=1643
  _globals['_REVOKEUSERPERMISSIONREQUEST']._serialized_start=1646
  _globals['_REVOKEUSERPERMISSIONREQUEST']._serialized_end=1810
  _globals['_REVOKEUSERPERMISSIONMETADATA']._serialized_start=1812
  _globals['_REVOKEUSERPERMISSIONMETADATA']._serialized_end=1881
  _globals['_USERSERVICE']._serialized_start=1884
  _globals['_USERSERVICE']._serialized_end=3337
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.video.v1.channel_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetChannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id"]) -> None: ...

global___GetChannelRequest = GetChannelRequest

@typing.final
class ListChannelsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the organization."""
    page_size: builtins.int
    """The maximum number of the results per page to return. Default value: 100."""
    page_token: builtins.str
    """Page token for getting the next page of the result."""
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "createdAt desc". "id asc" if omitted.
    Possible fields: ["id", "createdAt", "updatedAt"]
    Both snake_case and camelCase are supported for fields.
    """
    filter: builtins.str
    """Filter expression that filters resources listed in the response.
    Expressions are composed of terms connected by logic operators.
    Value in quotes: `'` or `"`
    Example: "key1='value' AND key2='value'"
    Supported operators: ["AND"].
    Supported fields: ["title"]
    Both snake_case and camelCase are supported for fields.
    """
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "order_by", b"order_by", "organization_id", b"organization_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListChannelsRequest = ListChannelsRequest

@typing.final
class ListChannelsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNELS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page."""
    @property
    def channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.channel_pb2.Channel]:
        """List of channels for specific organization."""

    def __init__(
        self,
        *,
        channels: collections.abc.Iterable[yandex.cloud.video.v1.channel_pb2.Channel] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channels", b"channels", "next_page_token", b"next_page_token"]) -> None: ...

global___ListChannelsResponse = ListChannelsResponse

@typing.final
class CreateChannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the organization."""
    title: builtins.str
    """Channel title."""
    description: builtins.str
    """Channel description."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels as `` key:value `` pairs. Maximum 64 per resource."""

    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels", "organization_id", b"organization_id", "title", b"title"]) -> None: ...

global___CreateChannelRequest = CreateChannelRequest

@typing.final
class CreateChannelMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id"]) -> None: ...

global___CreateChannelMetadata = CreateChannelMetadata

@typing.final
class UpdateChannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    FIELD_MASK_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    title: builtins.str
    """Channel title."""
    description: builtins.str
    """Channel description."""
    @property
    def field_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the channel are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels as `` key:value `` pairs. Maximum 64 per resource."""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        field_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["field_mask", b"field_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "description", b"description", "field_mask", b"field_mask", "labels", b"labels", "title", b"title"]) -> None: ...

global___UpdateChannelRequest = UpdateChannelRequest

@typing.final
class UpdateChannelMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id"]) -> None: ...

global___UpdateChannelMetadata = UpdateChannelMetadata

@typing.final
class DeleteChannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id"]) -> None: ...

global___DeleteChannelRequest = DeleteChannelRequest

@typing.final
class DeleteChannelMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id"]) -> None: ...

global___DeleteChannelMetadata = DeleteChannelMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _CompressionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CompressionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CompressionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    COMPRESSION_TYPE_UNSPECIFIED: _CompressionType.ValueType  # 0
    COMPRESSION_TYPE_UNCOMPRESSED: _CompressionType.ValueType  # 1
    """no codec (uncompressed)."""
    COMPRESSION_TYPE_ZSTD: _CompressionType.ValueType  # 2
    """Zstandard codec."""
    COMPRESSION_TYPE_LZ4: _CompressionType.ValueType  # 3
    """LZ4 codec."""
    COMPRESSION_TYPE_SNAPPY: _CompressionType.ValueType  # 4
    """Snappy codec."""
    COMPRESSION_TYPE_GZIP: _CompressionType.ValueType  # 5
    """GZip codec."""
    COMPRESSION_TYPE_PRODUCER: _CompressionType.ValueType  # 6
    """the codec to use is set by a producer (can be any of `ZSTD`, `LZ4`, `GZIP` or `SNAPPY` codecs)."""

class CompressionType(_CompressionType, metaclass=_CompressionTypeEnumTypeWrapper): ...

COMPRESSION_TYPE_UNSPECIFIED: CompressionType.ValueType  # 0
COMPRESSION_TYPE_UNCOMPRESSED: CompressionType.ValueType  # 1
"""no codec (uncompressed)."""
COMPRESSION_TYPE_ZSTD: CompressionType.ValueType  # 2
"""Zstandard codec."""
COMPRESSION_TYPE_LZ4: CompressionType.ValueType  # 3
"""LZ4 codec."""
COMPRESSION_TYPE_SNAPPY: CompressionType.ValueType  # 4
"""Snappy codec."""
COMPRESSION_TYPE_GZIP: CompressionType.ValueType  # 5
"""GZip codec."""
COMPRESSION_TYPE_PRODUCER: CompressionType.ValueType  # 6
"""the codec to use is set by a producer (can be any of `ZSTD`, `LZ4`, `GZIP` or `SNAPPY` codecs)."""
global___CompressionType = CompressionType

class _SaslMechanism:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SaslMechanismEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SaslMechanism.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SASL_MECHANISM_UNSPECIFIED: _SaslMechanism.ValueType  # 0
    SASL_MECHANISM_SCRAM_SHA_256: _SaslMechanism.ValueType  # 1
    SASL_MECHANISM_SCRAM_SHA_512: _SaslMechanism.ValueType  # 2

class SaslMechanism(_SaslMechanism, metaclass=_SaslMechanismEnumTypeWrapper): ...

SASL_MECHANISM_UNSPECIFIED: SaslMechanism.ValueType  # 0
SASL_MECHANISM_SCRAM_SHA_256: SaslMechanism.ValueType  # 1
SASL_MECHANISM_SCRAM_SHA_512: SaslMechanism.ValueType  # 2
global___SaslMechanism = SaslMechanism



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/speechsense/v1/analysis/text_classifiers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;yandex/cloud/speechsense/v1/analysis/text_classifiers.proto\x12$yandex.cloud.speechsense.v1.analysis\x1a\x1egoogle/protobuf/wrappers.proto\"l\n\x0fTextClassifiers\x12Y\n\x15\x63lassification_result\x18\x01 \x03(\x0b\x32:.yandex.cloud.speechsense.v1.analysis.ClassificationResult\"\x85\x01\n\x14\x43lassificationResult\x12\x12\n\nclassifier\x18\x01 \x01(\t\x12Y\n\x15\x63lassifier_statistics\x18\x02 \x03(\x0b\x32:.yandex.cloud.speechsense.v1.analysis.ClassifierStatistics\"\xa5\x01\n\x14\x43lassifierStatistics\x12\x33\n\x0e\x63hannel_number\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x13\n\x0btotal_count\x18\x02 \x01(\x03\x12\x43\n\nhistograms\x18\x03 \x03(\x0b\x32/.yandex.cloud.speechsense.v1.analysis.Histogram\"!\n\tHistogram\x12\x14\n\x0c\x63ount_values\x18\x01 \x03(\x03\x42\x96\x01\n(yandex.cloud.api.speechsense.v1.analysisB\x14TextClassifiersProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.analysis.text_classifiers_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.speechsense.v1.analysisB\024TextClassifiersProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsense'
  _globals['_TEXTCLASSIFIERS']._serialized_start=133
  _globals['_TEXTCLASSIFIERS']._serialized_end=241
  _globals['_CLASSIFICATIONRESULT']._serialized_start=244
  _globals['_CLASSIFICATIONRESULT']._serialized_end=377
  _globals['_CLASSIFIERSTATISTICS']._serialized_start=380
  _globals['_CLASSIFIERSTATISTICS']._serialized_end=545
  _globals['_HISTOGRAM']._serialized_start=547
  _globals['_HISTOGRAM']._serialized_end=580
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/snapshot_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1 import snapshot_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/compute/v1/snapshot_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/compute/v1/snapshot.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"7\n\x12GetSnapshotRequest\x12!\n\x0bsnapshot_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xae\x01\n\x14ListSnapshotsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"f\n\x15ListSnapshotsResponse\x12\x34\n\tsnapshots\x18\x01 \x03(\x0b\x32!.yandex.cloud.compute.v1.Snapshot\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xf2\x02\n\x15\x43reateSnapshotRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x07\x64isk_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8f\x01\n\x06labels\x18\x06 \x03(\x0b\x32:.yandex.cloud.compute.v1.CreateSnapshotRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x05\x10\x06\">\n\x16\x43reateSnapshotMetadata\x12\x13\n\x0bsnapshot_id\x18\x01 \x01(\t\x12\x0f\n\x07\x64isk_id\x18\x02 \x01(\t\"\x80\x03\n\x15UpdateSnapshotRequest\x12!\n\x0bsnapshot_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8f\x01\n\x06labels\x18\x05 \x03(\x0b\x32:.yandex.cloud.compute.v1.UpdateSnapshotRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16UpdateSnapshotMetadata\x12\x13\n\x0bsnapshot_id\x18\x01 \x01(\t\":\n\x15\x44\x65leteSnapshotRequest\x12!\n\x0bsnapshot_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x16\x44\x65leteSnapshotMetadata\x12\x13\n\x0bsnapshot_id\x18\x01 \x01(\t\"\x80\x01\n\x1dListSnapshotOperationsRequest\x12!\n\x0bsnapshot_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"p\n\x1eListSnapshotOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xa3\r\n\x0fSnapshotService\x12\x82\x01\n\x03Get\x12+.yandex.cloud.compute.v1.GetSnapshotRequest\x1a!.yandex.cloud.compute.v1.Snapshot\"+\x82\xd3\xe4\x93\x02%\x12#/compute/v1/snapshots/{snapshot_id}\x12\x84\x01\n\x04List\x12-.yandex.cloud.compute.v1.ListSnapshotsRequest\x1a..yandex.cloud.compute.v1.ListSnapshotsResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/compute/v1/snapshots\x12\xa3\x01\n\x06\x43reate\x12..yandex.cloud.compute.v1.CreateSnapshotRequest\x1a!.yandex.cloud.operation.Operation\"F\xb2\xd2*\"\n\x16\x43reateSnapshotMetadata\x12\x08Snapshot\x82\xd3\xe4\x93\x02\x1a\"\x15/compute/v1/snapshots:\x01*\x12\xb1\x01\n\x06Update\x12..yandex.cloud.compute.v1.UpdateSnapshotRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2*\"\n\x16UpdateSnapshotMetadata\x12\x08Snapshot\x82\xd3\xe4\x93\x02(2#/compute/v1/snapshots/{snapshot_id}:\x01*\x12\xbb\x01\n\x06\x44\x65lete\x12..yandex.cloud.compute.v1.DeleteSnapshotRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*/\n\x16\x44\x65leteSnapshotMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02%*#/compute/v1/snapshots/{snapshot_id}\x12\xb9\x01\n\x0eListOperations\x12\x36.yandex.cloud.compute.v1.ListSnapshotOperationsRequest\x1a\x37.yandex.cloud.compute.v1.ListSnapshotOperationsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./compute/v1/snapshots/{snapshot_id}/operations\x12\xb5\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/compute/v1/snapshots/{resource_id}:listAccessBindings\x12\xf4\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8c\x01\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02:\"5/compute/v1/snapshots/{resource_id}:setAccessBindings:\x01*\x12\x80\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x92\x01\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02=\"8/compute/v1/snapshots/{resource_id}:updateAccessBindings:\x01*Bb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.snapshot_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _GETSNAPSHOTREQUEST.fields_by_name['snapshot_id']._options = None
  _GETSNAPSHOTREQUEST.fields_by_name['snapshot_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSNAPSHOTSREQUEST.fields_by_name['folder_id']._options = None
  _LISTSNAPSHOTSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSNAPSHOTSREQUEST.fields_by_name['page_size']._options = None
  _LISTSNAPSHOTSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTSNAPSHOTSREQUEST.fields_by_name['page_token']._options = None
  _LISTSNAPSHOTSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTSNAPSHOTSREQUEST.fields_by_name['filter']._options = None
  _LISTSNAPSHOTSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTSNAPSHOTSREQUEST.fields_by_name['order_by']._options = None
  _LISTSNAPSHOTSREQUEST.fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _CREATESNAPSHOTREQUEST_LABELSENTRY._options = None
  _CREATESNAPSHOTREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATESNAPSHOTREQUEST.fields_by_name['folder_id']._options = None
  _CREATESNAPSHOTREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATESNAPSHOTREQUEST.fields_by_name['disk_id']._options = None
  _CREATESNAPSHOTREQUEST.fields_by_name['disk_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATESNAPSHOTREQUEST.fields_by_name['name']._options = None
  _CREATESNAPSHOTREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _CREATESNAPSHOTREQUEST.fields_by_name['description']._options = None
  _CREATESNAPSHOTREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATESNAPSHOTREQUEST.fields_by_name['labels']._options = None
  _CREATESNAPSHOTREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _UPDATESNAPSHOTREQUEST_LABELSENTRY._options = None
  _UPDATESNAPSHOTREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATESNAPSHOTREQUEST.fields_by_name['snapshot_id']._options = None
  _UPDATESNAPSHOTREQUEST.fields_by_name['snapshot_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATESNAPSHOTREQUEST.fields_by_name['name']._options = None
  _UPDATESNAPSHOTREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _UPDATESNAPSHOTREQUEST.fields_by_name['description']._options = None
  _UPDATESNAPSHOTREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATESNAPSHOTREQUEST.fields_by_name['labels']._options = None
  _UPDATESNAPSHOTREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _DELETESNAPSHOTREQUEST.fields_by_name['snapshot_id']._options = None
  _DELETESNAPSHOTREQUEST.fields_by_name['snapshot_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSNAPSHOTOPERATIONSREQUEST.fields_by_name['snapshot_id']._options = None
  _LISTSNAPSHOTOPERATIONSREQUEST.fields_by_name['snapshot_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSNAPSHOTOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTSNAPSHOTOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTSNAPSHOTOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTSNAPSHOTOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _SNAPSHOTSERVICE.methods_by_name['Get']._options = None
  _SNAPSHOTSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002%\022#/compute/v1/snapshots/{snapshot_id}'
  _SNAPSHOTSERVICE.methods_by_name['List']._options = None
  _SNAPSHOTSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\027\022\025/compute/v1/snapshots'
  _SNAPSHOTSERVICE.methods_by_name['Create']._options = None
  _SNAPSHOTSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateSnapshotMetadata\022\010Snapshot\202\323\344\223\002\032\"\025/compute/v1/snapshots:\001*'
  _SNAPSHOTSERVICE.methods_by_name['Update']._options = None
  _SNAPSHOTSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateSnapshotMetadata\022\010Snapshot\202\323\344\223\002(2#/compute/v1/snapshots/{snapshot_id}:\001*'
  _SNAPSHOTSERVICE.methods_by_name['Delete']._options = None
  _SNAPSHOTSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteSnapshotMetadata\022\025google.protobuf.Empty\202\323\344\223\002%*#/compute/v1/snapshots/{snapshot_id}'
  _SNAPSHOTSERVICE.methods_by_name['ListOperations']._options = None
  _SNAPSHOTSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0020\022./compute/v1/snapshots/{snapshot_id}/operations'
  _SNAPSHOTSERVICE.methods_by_name['ListAccessBindings']._options = None
  _SNAPSHOTSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\0028\0226/compute/v1/snapshots/{resource_id}:listAccessBindings'
  _SNAPSHOTSERVICE.methods_by_name['SetAccessBindings']._options = None
  _SNAPSHOTSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002:\"5/compute/v1/snapshots/{resource_id}:setAccessBindings:\001*'
  _SNAPSHOTSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _SNAPSHOTSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002=\"8/compute/v1/snapshots/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETSNAPSHOTREQUEST']._serialized_start=318
  _globals['_GETSNAPSHOTREQUEST']._serialized_end=373
  _globals['_LISTSNAPSHOTSREQUEST']._serialized_start=376
  _globals['_LISTSNAPSHOTSREQUEST']._serialized_end=550
  _globals['_LISTSNAPSHOTSRESPONSE']._serialized_start=552
  _globals['_LISTSNAPSHOTSRESPONSE']._serialized_end=654
  _globals['_CREATESNAPSHOTREQUEST']._serialized_start=657
  _globals['_CREATESNAPSHOTREQUEST']._serialized_end=1027
  _globals['_CREATESNAPSHOTREQUEST_LABELSENTRY']._serialized_start=976
  _globals['_CREATESNAPSHOTREQUEST_LABELSENTRY']._serialized_end=1021
  _globals['_CREATESNAPSHOTMETADATA']._serialized_start=1029
  _globals['_CREATESNAPSHOTMETADATA']._serialized_end=1091
  _globals['_UPDATESNAPSHOTREQUEST']._serialized_start=1094
  _globals['_UPDATESNAPSHOTREQUEST']._serialized_end=1478
  _globals['_UPDATESNAPSHOTREQUEST_LABELSENTRY']._serialized_start=976
  _globals['_UPDATESNAPSHOTREQUEST_LABELSENTRY']._serialized_end=1021
  _globals['_UPDATESNAPSHOTMETADATA']._serialized_start=1480
  _globals['_UPDATESNAPSHOTMETADATA']._serialized_end=1525
  _globals['_DELETESNAPSHOTREQUEST']._serialized_start=1527
  _globals['_DELETESNAPSHOTREQUEST']._serialized_end=1585
  _globals['_DELETESNAPSHOTMETADATA']._serialized_start=1587
  _globals['_DELETESNAPSHOTMETADATA']._serialized_end=1632
  _globals['_LISTSNAPSHOTOPERATIONSREQUEST']._serialized_start=1635
  _globals['_LISTSNAPSHOTOPERATIONSREQUEST']._serialized_end=1763
  _globals['_LISTSNAPSHOTOPERATIONSRESPONSE']._serialized_start=1765
  _globals['_LISTSNAPSHOTOPERATIONSRESPONSE']._serialized_end=1877
  _globals['_SNAPSHOTSERVICE']._serialized_start=1880
  _globals['_SNAPSHOTSERVICE']._serialized_end=3579
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.marketplace.licensemanager.v1.instance_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetInstanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_ID_FIELD_NUMBER: builtins.int
    instance_id: builtins.str
    """ID of the subscription instance."""
    def __init__(
        self,
        *,
        instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_id", b"instance_id"]) -> None: ...

global___GetInstanceRequest = GetInstanceRequest

@typing.final
class ListInstancesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that the subscription instance belongs to."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListInstancesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListInstancesResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters subscription instances listed in the response.

    The expression must specify:
    1. The field name. Currently you can use filtering only on [Instance.name] field.
    2. An operator. Can be either `=` or `!=` for single values, `IN` or `NOT IN` for lists of values.
    3. The value. Must be in double quotes `""`. Must be 3-63 characters long and match the regular expression `^[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name="my-subscription-instance"`.
    """
    order_by: builtins.str
    """Sorting order for the list of subscription instances."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListInstancesRequest = ListInstancesRequest

@typing.final
class ListInstancesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListInstancesRequest.page_size], use `next_page_token` as the value
    for the [ListInstancesRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.marketplace.licensemanager.v1.instance_pb2.Instance]:
        """List of subscription instances."""

    def __init__(
        self,
        *,
        instances: collections.abc.Iterable[yandex.cloud.marketplace.licensemanager.v1.instance_pb2.Instance] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instances", b"instances", "next_page_token", b"next_page_token"]) -> None: ...

global___ListInstancesResponse = ListInstancesResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.vpc.v1.security_group_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetSecurityGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_GROUP_ID_FIELD_NUMBER: builtins.int
    security_group_id: builtins.str
    """ID of the Security Group resource to return.
    To get the security group ID, use a [SecurityGroup.List] request.
    """
    def __init__(
        self,
        *,
        security_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["security_group_id", b"security_group_id"]) -> None: ...

global___GetSecurityGroupRequest = GetSecurityGroupRequest

@typing.final
class ListSecurityGroupsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list security groups in.
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListSecurityGroupsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests. Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListSecurityGroupsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on the [SecurityGroup.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    filter by network_id is here
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListSecurityGroupsRequest = ListSecurityGroupsRequest

@typing.final
class ListSecurityGroupsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListNetworksRequest.page_size], use
    the [next_page_token] as the value
    for the [ListNetworksRequest.page_token] query parameter
    in the next list request. Subsequent list requests will have their own
    [next_page_token] to continue paging through the results.
    """
    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.vpc.v1.security_group_pb2.SecurityGroup]:
        """List of SecurityGroup resources."""

    def __init__(
        self,
        *,
        security_groups: collections.abc.Iterable[yandex.cloud.vpc.v1.security_group_pb2.SecurityGroup] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "security_groups", b"security_groups"]) -> None: ...

global___ListSecurityGroupsResponse = ListSecurityGroupsResponse

@typing.final
class CreateSecurityGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    RULE_SPECS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder for this request to create a security group in.
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the security group.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the security group."""
    network_id: builtins.str
    """ID of the Network to create security group for."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs."""

    @property
    def rule_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SecurityGroupRuleSpec]:
        """Security rules specifications."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        network_id: builtins.str = ...,
        rule_specs: collections.abc.Iterable[global___SecurityGroupRuleSpec] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "network_id", b"network_id", "rule_specs", b"rule_specs"]) -> None: ...

global___CreateSecurityGroupRequest = CreateSecurityGroupRequest

@typing.final
class SecurityGroupRuleSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    PROTOCOL_NAME_FIELD_NUMBER: builtins.int
    PROTOCOL_NUMBER_FIELD_NUMBER: builtins.int
    CIDR_BLOCKS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_ID_FIELD_NUMBER: builtins.int
    PREDEFINED_TARGET_FIELD_NUMBER: builtins.int
    description: builtins.str
    """Description of the security rule."""
    direction: yandex.cloud.vpc.v1.security_group_pb2.SecurityGroupRule.Direction.ValueType
    """The direction of network traffic allowed by this rule."""
    protocol_name: builtins.str
    """Protocol name."""
    protocol_number: builtins.int
    """Protocol number from [IANA protocol numbers](https://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml)."""
    security_group_id: builtins.str
    """ID of the security group to add rule to."""
    predefined_target: builtins.str
    """Predefined target. See [security groups rules](/docs/vpc/concepts/security-groups#security-groups-rules) for more information.
    string subnet_id = .. ;
    """
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Rule labels as `` key:value `` pairs."""

    @property
    def ports(self) -> yandex.cloud.vpc.v1.security_group_pb2.PortRange:
        """The range of ports that allow traffic to pass through. Null value means any port.
        null value means any port
        """

    @property
    def cidr_blocks(self) -> yandex.cloud.vpc.v1.security_group_pb2.CidrBlocks:
        """CIDR blocks to allow to recieve or send traffic."""

    def __init__(
        self,
        *,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        direction: yandex.cloud.vpc.v1.security_group_pb2.SecurityGroupRule.Direction.ValueType = ...,
        ports: yandex.cloud.vpc.v1.security_group_pb2.PortRange | None = ...,
        protocol_name: builtins.str = ...,
        protocol_number: builtins.int = ...,
        cidr_blocks: yandex.cloud.vpc.v1.security_group_pb2.CidrBlocks | None = ...,
        security_group_id: builtins.str = ...,
        predefined_target: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cidr_blocks", b"cidr_blocks", "ports", b"ports", "predefined_target", b"predefined_target", "protocol", b"protocol", "protocol_name", b"protocol_name", "protocol_number", b"protocol_number", "security_group_id", b"security_group_id", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cidr_blocks", b"cidr_blocks", "description", b"description", "direction", b"direction", "labels", b"labels", "ports", b"ports", "predefined_target", b"predefined_target", "protocol", b"protocol", "protocol_name", b"protocol_name", "protocol_number", b"protocol_number", "security_group_id", b"security_group_id", "target", b"target"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["protocol", b"protocol"]) -> typing.Literal["protocol_name", "protocol_number"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["target", b"target"]) -> typing.Literal["cidr_blocks", "security_group_id", "predefined_target"] | None: ...

global___SecurityGroupRuleSpec = SecurityGroupRuleSpec

@typing.final
class CreateSecurityGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_GROUP_ID_FIELD_NUMBER: builtins.int
    security_group_id: builtins.str
    """ID of the security group that is being created."""
    def __init__(
        self,
        *,
        security_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["security_group_id", b"security_group_id"]) -> None: ...

global___CreateSecurityGroupMetadata = CreateSecurityGroupMetadata

@typing.final
class UpdateSecurityGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    SECURITY_GROUP_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    RULE_SPECS_FIELD_NUMBER: builtins.int
    security_group_id: builtins.str
    """ID of the security group to update.

    To get the security group ID make a [SecurityGroupService.List] request.
    """
    name: builtins.str
    """New name for the security group.
    The name must be unique within the folder.
    """
    description: builtins.str
    """New description of the security group."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the Address should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Security group labels as `key:value` pairs.

        Existing set of labels is completely replaced by the provided set, so if you just want
        to add or remove a label:
        1. Get the current set of labels with a [SecurityGroupService.Get] request.
        2. Add or remove a label in this set.
        3. Send the new set in this field.
        """

    @property
    def rule_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SecurityGroupRuleSpec]:
        """Updated rule list. All existing rules will be replaced with given list."""

    def __init__(
        self,
        *,
        security_group_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        rule_specs: collections.abc.Iterable[global___SecurityGroupRuleSpec] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels", "name", b"name", "rule_specs", b"rule_specs", "security_group_id", b"security_group_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateSecurityGroupRequest = UpdateSecurityGroupRequest

@typing.final
class UpdateSecurityGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_GROUP_ID_FIELD_NUMBER: builtins.int
    ADDED_RULE_IDS_FIELD_NUMBER: builtins.int
    security_group_id: builtins.str
    """ID of the SecurityGroup that is being updated."""
    @property
    def added_rule_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of added security rules IDs."""

    def __init__(
        self,
        *,
        security_group_id: builtins.str = ...,
        added_rule_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["added_rule_ids", b"added_rule_ids", "security_group_id", b"security_group_id"]) -> None: ...

global___UpdateSecurityGroupMetadata = UpdateSecurityGroupMetadata

@typing.final
class UpdateSecurityGroupRulesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_GROUP_ID_FIELD_NUMBER: builtins.int
    DELETION_RULE_IDS_FIELD_NUMBER: builtins.int
    ADDITION_RULE_SPECS_FIELD_NUMBER: builtins.int
    security_group_id: builtins.str
    """ID of the SecurityGroup that is being updated with new rules."""
    @property
    def deletion_rule_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of rules IDs to delete."""

    @property
    def addition_rule_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SecurityGroupRuleSpec]:
        """Security rules specifications."""

    def __init__(
        self,
        *,
        security_group_id: builtins.str = ...,
        deletion_rule_ids: collections.abc.Iterable[builtins.str] | None = ...,
        addition_rule_specs: collections.abc.Iterable[global___SecurityGroupRuleSpec] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["addition_rule_specs", b"addition_rule_specs", "deletion_rule_ids", b"deletion_rule_ids", "security_group_id", b"security_group_id"]) -> None: ...

global___UpdateSecurityGroupRulesRequest = UpdateSecurityGroupRulesRequest

@typing.final
class UpdateSecurityGroupRuleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    SECURITY_GROUP_ID_FIELD_NUMBER: builtins.int
    RULE_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    security_group_id: builtins.str
    """ID of the SecurityGroup to update rule in."""
    rule_id: builtins.str
    """ID of the rule to update."""
    description: builtins.str
    """New description of the rule."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the Address should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Rule labels as `key:value` pairs.

        Existing set of labels is completely replaced by the provided set, so if you just want
        to add or remove a label:
        1. Get the current set of labels with a [AddressService.Get] request.
        2. Add or remove a label in this set.
        3. Send the new set in this field.
        """

    def __init__(
        self,
        *,
        security_group_id: builtins.str = ...,
        rule_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels", "rule_id", b"rule_id", "security_group_id", b"security_group_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateSecurityGroupRuleRequest = UpdateSecurityGroupRuleRequest

@typing.final
class UpdateSecurityGroupRuleMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_GROUP_ID_FIELD_NUMBER: builtins.int
    RULE_ID_FIELD_NUMBER: builtins.int
    security_group_id: builtins.str
    """ID of the SecurityGroup that is being updated with new rules."""
    rule_id: builtins.str
    """ID of the rule that is being updated."""
    def __init__(
        self,
        *,
        security_group_id: builtins.str = ...,
        rule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["rule_id", b"rule_id", "security_group_id", b"security_group_id"]) -> None: ...

global___UpdateSecurityGroupRuleMetadata = UpdateSecurityGroupRuleMetadata

@typing.final
class DeleteSecurityGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_GROUP_ID_FIELD_NUMBER: builtins.int
    security_group_id: builtins.str
    """ID of the security group to delete.

    To get a address ID make a [SecurityGroup.List] request.
    """
    def __init__(
        self,
        *,
        security_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["security_group_id", b"security_group_id"]) -> None: ...

global___DeleteSecurityGroupRequest = DeleteSecurityGroupRequest

@typing.final
class DeleteSecurityGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_GROUP_ID_FIELD_NUMBER: builtins.int
    security_group_id: builtins.str
    """ID of the SecurityGroup that is being deleted."""
    def __init__(
        self,
        *,
        security_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["security_group_id", b"security_group_id"]) -> None: ...

global___DeleteSecurityGroupMetadata = DeleteSecurityGroupMetadata

@typing.final
class ListSecurityGroupOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    security_group_id: builtins.str
    """ID of the address to list operations for.

    To get a address ID make a [SecurityGroup.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListSecurityGroupOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListSecurityGroupOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        security_group_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "security_group_id", b"security_group_id"]) -> None: ...

global___ListSecurityGroupOperationsRequest = ListSecurityGroupOperationsRequest

@typing.final
class ListSecurityGroupOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListSecurityGroupOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListSecurityGroupOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified security group."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListSecurityGroupOperationsResponse = ListSecurityGroupOperationsResponse

@typing.final
class MoveSecurityGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_GROUP_ID_FIELD_NUMBER: builtins.int
    DESTINATION_FOLDER_ID_FIELD_NUMBER: builtins.int
    security_group_id: builtins.str
    """ID of the security group to move."""
    destination_folder_id: builtins.str
    """ID of the folder to move security group to."""
    def __init__(
        self,
        *,
        security_group_id: builtins.str = ...,
        destination_folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["destination_folder_id", b"destination_folder_id", "security_group_id", b"security_group_id"]) -> None: ...

global___MoveSecurityGroupRequest = MoveSecurityGroupRequest

@typing.final
class MoveSecurityGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_GROUP_ID_FIELD_NUMBER: builtins.int
    security_group_id: builtins.str
    """ID of the security group that is being moved."""
    def __init__(
        self,
        *,
        security_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["security_group_id", b"security_group_id"]) -> None: ...

global___MoveSecurityGroupMetadata = MoveSecurityGroupMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.compute.v1.image_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetImageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the Image resource to return.
    To get the image ID, use a [ImageService.List] request.
    """
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___GetImageRequest = GetImageRequest

@typing.final
class GetImageLatestByFamilyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    FAMILY_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to get the image from.
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    family: builtins.str
    """Name of the image family to search for."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        family: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["family", b"family", "folder_id", b"folder_id"]) -> None: ...

global___GetImageLatestByFamilyRequest = GetImageLatestByFamilyRequest

@typing.final
class ListImagesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list images in.
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListImagesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListImagesResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression consists of one or more conditions united by `AND` operator: `<condition1> [AND <condition2> [<...> AND <conditionN>]]`.

    Each condition has the form `<field> <operator> <value>`, where:
    1. `<field>` is the field name. Currently you can use filtering only on the limited number of fields.
    2. `<operator>` is a logical operator, one of `=`, `!=`, `IN`, `NOT IN`.
    3. `<value>` represents a value.
    String values should be written in double (`"`) or single (`'`) quotes. C-style escape sequences are supported (`\\"` turns to `"`, `\\'` to `'`, `\\\\` to backslash).
    """
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "createdAt desc". "id asc" if omitted.
    The default sorting order is ascending
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListImagesRequest = ListImagesRequest

@typing.final
class ListImagesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListSnapshotsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListSnapshotsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def images(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.image_pb2.Image]:
        """List of images."""

    def __init__(
        self,
        *,
        images: collections.abc.Iterable[yandex.cloud.compute.v1.image_pb2.Image] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["images", b"images", "next_page_token", b"next_page_token"]) -> None: ...

global___ListImagesResponse = ListImagesResponse

@typing.final
class CreateImageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    FAMILY_FIELD_NUMBER: builtins.int
    MIN_DISK_SIZE_FIELD_NUMBER: builtins.int
    PRODUCT_IDS_FIELD_NUMBER: builtins.int
    IMAGE_ID_FIELD_NUMBER: builtins.int
    DISK_ID_FIELD_NUMBER: builtins.int
    SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    OS_FIELD_NUMBER: builtins.int
    POOLED_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create an image in.
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the image."""
    description: builtins.str
    """Description of the image."""
    family: builtins.str
    """The name of the image family to which this image belongs. For more information, see [Image family](/docs/compute/concepts/image#family).

    To get an information about the most recent image from a family, use a [ImageService.GetLatestByFamily] request.
    """
    min_disk_size: builtins.int
    """Minimum size of the disk that will be created from this image.
    Specified in bytes. Should be more than the volume of source data.
    optional, should be > source data
    """
    image_id: builtins.str
    """ID of the source image to create the new image from."""
    disk_id: builtins.str
    """ID of the disk to create the image from."""
    snapshot_id: builtins.str
    """ID of the snapshot to create the image from."""
    uri: builtins.str
    """URI of the source image to create the new image from.
    Currently only supports links to images that are stored in Object Storage.
    Currently only supports Qcow2, VMDK, and RAW formats.
    """
    pooled: builtins.bool
    """When true, an image pool will be created for fast creation disks from the image."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def product_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """License IDs that indicate which licenses are attached to this resource.
        License IDs are used to calculate additional charges for the use of the virtual machine.

        The correct license ID is generated by the platform. IDs are inherited by new resources created from this resource.

        If you know the license IDs, specify them when you create the image.
        For example, if you create a disk image using a third-party utility and load it into Object Storage, the license IDs will be lost.
        You can specify them in this request.
        """

    @property
    def os(self) -> yandex.cloud.compute.v1.image_pb2.Os:
        """Operating system that is contained in the image.

        If not specified and you used the `image_id` or `disk_id` field to set the source, then the value can be inherited from the source resource.
        """

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        family: builtins.str = ...,
        min_disk_size: builtins.int = ...,
        product_ids: collections.abc.Iterable[builtins.str] | None = ...,
        image_id: builtins.str = ...,
        disk_id: builtins.str = ...,
        snapshot_id: builtins.str = ...,
        uri: builtins.str = ...,
        os: yandex.cloud.compute.v1.image_pb2.Os | None = ...,
        pooled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["disk_id", b"disk_id", "image_id", b"image_id", "os", b"os", "snapshot_id", b"snapshot_id", "source", b"source", "uri", b"uri"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "disk_id", b"disk_id", "family", b"family", "folder_id", b"folder_id", "image_id", b"image_id", "labels", b"labels", "min_disk_size", b"min_disk_size", "name", b"name", "os", b"os", "pooled", b"pooled", "product_ids", b"product_ids", "snapshot_id", b"snapshot_id", "source", b"source", "uri", b"uri"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["source", b"source"]) -> typing.Literal["image_id", "disk_id", "snapshot_id", "uri"] | None: ...

global___CreateImageRequest = CreateImageRequest

@typing.final
class CreateImageMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the image that is being created."""
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___CreateImageMetadata = CreateImageMetadata

@typing.final
class UpdateImageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    IMAGE_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    MIN_DISK_SIZE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the Image resource to update.
    To get the image ID, use a [ImageService.List] request.
    """
    name: builtins.str
    """Name of the image."""
    description: builtins.str
    """Description of the image."""
    min_disk_size: builtins.int
    """Minimum size of the disk that can be created from this image.
    Specified in bytes. Should be more than the volume of source data and more than the virtual disk size.
    """
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Image resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs.

        Existing set of `labels` is completely replaced by the provided set.
        """

    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        min_disk_size: builtins.int = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "image_id", b"image_id", "labels", b"labels", "min_disk_size", b"min_disk_size", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateImageRequest = UpdateImageRequest

@typing.final
class UpdateImageMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the Image resource that is being updated."""
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___UpdateImageMetadata = UpdateImageMetadata

@typing.final
class DeleteImageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the image to delete.
    To get the image ID, use a [ImageService.List] request.
    """
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___DeleteImageRequest = DeleteImageRequest

@typing.final
class DeleteImageMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the image that is being deleted."""
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___DeleteImageMetadata = DeleteImageMetadata

@typing.final
class ListImageOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the Image resource to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListImageOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListImageOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListImageOperationsRequest = ListImageOperationsRequest

@typing.final
class ListImageOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListImageOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListImageOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified image."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListImageOperationsResponse = ListImageOperationsResponse
